Package: easybio
Title: Comprehensive Single-Cell Annotation and Transcriptomic Analysis
        Toolkit
Version: 1.2.3
Authors@R: 
    person("Wei", "Cui", email = "m2c.w@outlook.com", role = c("aut", "cre", "cph"), comment = c(ORCID = "0009-0004-8315-5899"))
Description: Provides a comprehensive toolkit for single-cell annotation with the 'CellMarker2.0' database (see Xia Li, Peng Wang, Yunpeng Zhang (2023) <doi: 10.1093/nar/gkac947>). Streamlines biological label assignment in single-cell RNA-seq data and facilitates transcriptomic analysis, including preparation of TCGA<https://portal.gdc.cancer.gov/> and GEO<https://www.ncbi.nlm.nih.gov/geo/> datasets, differential expression analysis and visualization of enrichment analysis results. Additional utility functions support various bioinformatics workflows. See Wei Cui (2024) <doi: 10.1101/2024.09.14.609619> for more details.
URL: https://github.com/person-c/easybio
BugReports: https://github.com/person-c/easybio/issues
License: MIT + file LICENSE
Encoding: UTF-8
RoxygenNote: 7.3.2
Imports: data.table (>= 1.15.0), checkmate, ggplot2, httr2, R6, xml2
Depends: R (>= 4.1.0)
LazyData: true
Suggests: litedown, patchwork, ggrepel, Seurat, limma, GEOquery, fgsea,
        edgeR, testthat (>= 3.0.0),
biocViews: limma, GEOquery, edgeR, fgsea
Language: en-US
VignetteBuilder: litedown
Config/testthat/edition: 3
NeedsCompilation: no
Packaged: 2025-10-02 15:01:41 UTC; m2cw
Author: Wei Cui [aut, cre, cph] (ORCID:
    <https://orcid.org/0009-0004-8315-5899>)
Maintainer: Wei Cui <m2c.w@outlook.com>
Repository: CRAN
Date/Publication: 2025-10-02 15:20:02 UTC
Built: R 4.6.0; ; 2026-04-28 02:33:28 UTC; unix
