# Generated by roxygen2: do not edit by hand

export(Artist)
export(available_ele)
export(available_tissue_class)
export(available_tissue_type)
export(check_marker)
export(dgeList)
export(dprocess_dgeList)
export(finsert)
export(get_attr)
export(get_marker)
export(groupStat)
export(groupStatI)
export(limmaFit)
export(list2dt)
export(list2graph)
export(matchCellMarker2)
export(plotEnrichment2)
export(plotGSEA)
export(plotMarkerDistribution)
export(plotORA)
export(plotPossibleCell)
export(plotRank)
export(plotSeuratDot)
export(plotVolcano)
export(prepare_geo)
export(prepare_tcga)
export(setSavedir)
export(setcolnames)
export(setrownames)
export(split_matrix)
export(suggest_best_match)
export(theme_publication)
export(tuneParameters)
export(uniprot_id_map)
export(workIn)
import(R6)
import(data.table)
import(ggplot2)
import(grDevices)
import(graphics)
import(stats)
import(utils)
importFrom(checkmate,assert_data_frame)
importFrom(checkmate,assert_string)
importFrom(checkmate,assert_subset)
importFrom(utils,download.file)
