
<!-- README.md is generated from README.Rmd. Please edit that file -->

# easybio

<!-- badges: start -->

[![CRAN
status](https://www.r-pkg.org/badges/version/easybio)](https://CRAN.R-project.org/package=easybio)
[![R-CMD-check](https://github.com/person-c/easybio/actions/workflows/R-CMD-check.yaml/badge.svg)](https://github.com/person-c/easybio/actions/workflows/R-CMD-check.yaml)
<!-- badges: end -->

## Installation and Usage

``` r
install.packages("easybio", repos = c("https://person-c.r-universe.dev", "https://cloud.r-project.org"))
```

To know how to use this package to do single cell annotation, see the
[article](https://doi.org/10.1101/2024.09.14.609619).

参考这个[视频](https://www.bilibili.com/video/BV1Gk9BYTEz9/)。

## Stay up-to-date

To learn the difference between development version and CRAN version,
see [NEWS](./NEWS.md).

## Citation

If you use the single-cell annotation functionality from `easybio`,
consider citing:

- <https://doi.org/10.1101/2024.09.14.609619>

- <https://doi.org/10.1093/nar/gkac947>
